==> weather-2.01.tar.bz2: weather/weather_net.h <==
/***************************************************************************
 *   Weather module for Kadu communicator                                  *
 *   2004 Micha Maek (bysk)                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEATHERNET_H
#define WEATHERNET_H

#include <qobject.h>
#include <qtextcodec.h>

#include "config_file.h"
#include "misc.h"

#include "weather_parser.h"

const int CONNECTION_TIMEOUT = 15000;
const int CONNECTION_COUNT = 2;

/**
	Klasa zajmujca si wyszukiwaniem kodu miejscowoci.
	Wyszukiwanie inicujuj si przez wywoanie findID(), a obsug realizuj gniazda
	finished(), redirected() i error()
**/
class SearchIDLocation : public QObject
{
	Q_OBJECT

	private:
		HttpClient httpclient;
		QTextCodec* decoder;
		QString strPage;
		QString url;
		WeatherParser parser;
		
		QTimer* timer_timeout;
		int timeoutCount;
		
		QString locName;
		int cfPos;
		
		const QStringList& weatherConfigFiles;
		QStringList names, codes;
		
		void encodeUrl(QString& str, const QString& enc);

	private slots:
		void downloadingFinished();
		void downloadingRedirected(QString link);
		void downloadingError();
		void connectionTimeout();
		
	public:
		SearchIDLocation(ConfigFile* cf, const QStringList& wCfFiles);
		~SearchIDLocation();
		bool findID(QString loc_name, int config_pos);
		const QStringList& getNames() { return names; }
		const QStringList& getCodes() { return codes; }
	
	signals:
		void finished();
		//void redirected(QString link);
		void error();
};

/**
	Zajmuje si pobraniem strony WWW oraz wydobyciem z niej
	informacji pogodowych.
**/
class GetForecast : public QObject
{
	Q_OBJECT
	
	private:
		QString url;
		HttpClient httpclient;
		QTextCodec* decoder;
		
		Forecast& forecast;
		WeatherParser parser;
		QString strPage;
		QString iconPath;
		
		QTimer* timer_timeout;
		int timeoutCount;
		
		//ConfigFile* moduleConfig;
		ConfigFile* wConfig;
	
	public:	
		GetForecast(ConfigFile* cf, Forecast& f);
		~GetForecast();
		void downloadForecast(const QString& configFile, const QString& locID);
	
	public slots:
		void downloadingFinished();
		void downloadingError();
		void connectionTimeout();
	
	signals:
		void finished();
		void error();
};

#endif // WEATHERNET_H

==> weather-2.02.tar.bz2: weather/weather_net.h <==
/***************************************************************************
 *   Weather module for Kadu communicator                                  *
 *   2004 Micha Maek (bysk)                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEATHERNET_H
#define WEATHERNET_H

#include <qobject.h>
#include <qtextcodec.h>
#include <qtimer.h>

#include "config_file.h"
#include "misc.h"

#include "weather_parser.h"

const int WEATHER_CONNECTION_TIMEOUT = 15000;
const int WEATHER_CONNECTION_COUNT = 2;

/**
	Kody bdw
**/
const int WEATHER_ERROR_PARSER = 1;
const int WEATHER_ERROR_CONNECTION = 2;

/**
	Klasa zajmujca si wyszukiwaniem kodu miejscowoci.
	Wyszukiwanie inicujuj si przez wywoanie findID(), a obsug realizuj gniazda
	finished(), redirected() i error()
**/
class SearchIDLocation : public QObject
{
	Q_OBJECT

	private:
		HttpClient httpclient;
		QTextCodec* decoder;
		QString strPage;
		QString host;
		QString url;
		WeatherParser parser;
		
		QTimer* timer_timeout;
		int timeoutCount;
		
		QString locName;
		int cfPos;
		
		const QStringList& weatherConfigFiles;
		QStringList names, codes;
		
		void encodeUrl(QString& str, const QString& enc);

	private slots:
		void downloadingFinished();
		void downloadingRedirected(QString link);
		void downloadingError();
		void connectionTimeout();
		
	public:
		SearchIDLocation(ConfigFile* cf, const QStringList& wCfFiles);
		~SearchIDLocation();
		bool findID(QString loc_name, int config_pos);
		const QStringList& getNames() { return names; }
		const QStringList& getCodes() { return codes; }
	
	signals:
		void finished();
		//void redirected(QString link);
		void error(QString url);
};

/**
	Zajmuje si pobraniem strony WWW oraz wydobyciem z niej
	informacji pogodowych.
**/
class GetForecast : public QObject
{
	Q_OBJECT
	
	private:
		QString host;
		QString url;
		HttpClient httpclient;
		QTextCodec* decoder;
		
		Forecast& forecast;
		WeatherParser parser;
		QString strPage;
		QString iconPath;
		
		QTimer* timer_timeout;
		int timeoutCount;
		
		//ConfigFile* moduleConfig;
		ConfigFile* wConfig;
	
	public:	
		GetForecast(ConfigFile* cf, Forecast& f);
		~GetForecast();
		void downloadForecast(const QString& configFile, const QString& locID);
	
	public slots:
		void downloadingFinished();
		void downloadingRedirected(QString link);
		void downloadingError();
		void connectionTimeout();
	
	signals:
		void finished();
		void error(int err, QString url);
};


void splitUrl(const QString& url, QString& host, QString& path);

#endif // WEATHERNET_H
